// LICENSE@@@
//
//      Copyright (c) 2009-2013 LG Electronics, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// @@@LICENSE

/*jslint white: true, onevar: true, undef: true, eqeqeq: true, plusplus: true, bitwise: true,
regexp: true, newcap: true, immed: true, nomen: false, maxerr: 500 */
/*global exports, _, Class, Assert, JSON, Utils, DB, PalmCall, Future, console, Birthday, Name, IMAddress, Organization, Address, ContactBackupHash, VCardFileReader, Relation, PropertyArray, DefaultPropertyHash, Contact, ContactLinkable, IO, PhoneNumber, EmailAddress, Url, Nickname */

var VCard = exports.VCard = Class.create({
	initialize: function (obj) {

	}
});

/////////////// vCard formatting ////////////////

VCard.VERSIONS = {
	TWO_POINT_ONE: "2.1",
	THREE: "3.0"
};

VCard.CHARSET = {
	ASCII: "US-ASCII",
	UTF8: "UTF-8"
};

//////////////// vCard data markers ///////////////

VCard.MARKERS = {
	BEGIN: "BEGIN:VCARD",
	SEPERATOR: ":",
	CHARSET_UTF8: "CHARSET=UTF-8",
	VERSION: "VERSION",
	NICKNAME: "NICKNAME",
	NAME: "N",
	FULL_NAME: "FN",
	COMPANY: "ORG",
	JOBTITLE: "TITLE",
	PHONE: "TEL",
	EMAIL: "EMAIL",
	ADDRESS: "ADR",
	BIRTHDAY: "BDAY",
	URL: "URL",
	NOTE: "NOTE",
	RELATED: "X-ABRELATEDNAMES",
	GTALK: "X-GTALK",
	GOOGLE: "X-GTALK",
	AIM: "X-AIM",
	MSN: "X-MSN",
	YAHOO: "X-YAHOO",
	JABBER: "X-JABBER",
	QQ: "X-QQ",
	ICQ: "X-ICQ",
	SKYPE: "X-SKYPE",
	IM: "X-IM",
	SPOUSE_ONE_LINE: "X-SPOUSE",
	CHILD_ONE_LINE: "X-CHILD",
	END: "END:VCARD"
};

VCard.TYPEMARKERS = {
	HOME: "HOME",
	WORK: "WORK",
	FAX: "FAX",
	FAX_WORK: "FAX_WORK",
	FAX_HOME: "FAX_HOME",
	CELL: "CELL",
	PAGER: "PAGER",
	MAIN: "MAIN",
	OTHER: "OTHER",

	// Relation Markers
	ASSISTANT: "ASSISTANT",
	BROTHER: "BROTHER",
	CHILD: "CHILD",
	FATHER: "FATHER",
	FRIEND: "FRIEND",
	MANAGER: "MANAGER",
	MOTHER: "MOTHER",
	PARENT: "PARENT",
	PARTNER: "PARTNER",
	RELATIVE: "RELATIVE",
	SISTER: "SISTER",
	SPOUSE: "SPOUSE",

	// These are meant to be shoved into the handleRelation method
	// when we are dealing with a one line relation object.
	// They ensure that the handleRelation method treats the type
	// correctly
	SPOUSE_ONE_LINER: "item1.X-ABLabel:_$!<SPOUSE>!$_",
	CHILD_ONE_LINER: "item1.X-ABLabel:_$!<CHILD>!$_",

	// These are not typically used. They are here for completeness
	REFERRED_BY: "REFFERRED_BY",
	DOMESTIC_PARTNER: "DOMESTIC_PARTNER"
};

////////////////// vCard type data ////////////////////

VCard.TYPES = { };

////////////////// Phone Numbers /////////////////////

VCard._PHONE_NUMBER_CONTACT_POINT_VALUE = {
	FAX_HOME: PhoneNumber.TYPE.PERSONAL_FAX,
	FAX_WORK: PhoneNumber.TYPE.WORK_FAX,
	HOME: PhoneNumber.TYPE.HOME,
	WORK: PhoneNumber.TYPE.WORK,
	CELL: PhoneNumber.TYPE.MOBILE,
	PAGER: PhoneNumber.TYPE.PAGER,
	MAIN: PhoneNumber.TYPE.MAIN,
	OTHER: PhoneNumber.TYPE.OTHER
};

VCard.TYPES.PHONE_NUMBER = {
	FAX: { VCARD_VALUE: VCard.TYPEMARKERS.FAX },
	FAX_HOME: { VCARD_VALUE: VCard.TYPEMARKERS.FAX_HOME, CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.FAX_HOME },
	FAX_WORK: { VCARD_VALUE: VCard.TYPEMARKERS.FAX_WORK, CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.FAX_WORK },
	HOME: { VCARD_VALUE: VCard.TYPEMARKERS.HOME, CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.HOME },
	WORK: { VCARD_VALUE: VCard.TYPEMARKERS.WORK, CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.WORK },
	CELL: { VCARD_VALUE: VCard.TYPEMARKERS.CELL, CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.CELL },
	PAGER: { VCARD_VALUE: VCard.TYPEMARKERS.PAGER, CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.PAGER },
	MAIN: { VCARD_VALUE: VCard.TYPEMARKERS.MAIN, CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.MAIN },
	OTHER: { CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.OTHER }
};

VCard.PHONE_LABELS = {
	HOME: { CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.HOME, LABELS: ["HOME", "VOICE"] },
	WORK: { CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.WORK, LABELS: ["WORK", "VOICE"] },
	CELL: { CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.CELL, LABELS: ["CELL", "VOICE"] },
	PAGER: { CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.PAGER, LABELS: ["PAGER"] },
	FAX_HOME: { CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.FAX_HOME, LABELS: ["HOME", "FAX"] },
	FAX_WORK: { CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.FAX_WORK, LABELS: ["WORK", "FAX"] },
	OTHER: { CONTACT_POINT_VALUE: VCard._PHONE_NUMBER_CONTACT_POINT_VALUE.OTHER, LABELS: ["OTHER"] }
};

///////////////// Emails //////////////////////

VCard._EMAIL_CONTACT_POINT_VALUE = {
	HOME: EmailAddress.TYPE.HOME,
	WORK: EmailAddress.TYPE.WORK,
	OTHER: EmailAddress.TYPE.OTHER
};

VCard.TYPES.EMAIL = {
	HOME: { VCARD_VALUE: VCard.TYPEMARKERS.HOME, CONTACT_POINT_VALUE: VCard._EMAIL_CONTACT_POINT_VALUE.HOME },
	WORK: { VCARD_VALUE: VCard.TYPEMARKERS.WORK, CONTACT_POINT_VALUE: VCard._EMAIL_CONTACT_POINT_VALUE.WORK },
	OTHER: { CONTACT_POINT_VALUE: VCard._EMAIL_CONTACT_POINT_VALUE.OTHER }
};

VCard.EMAIL_LABELS = {
	HOME: { CONTACT_POINT_VALUE: VCard._EMAIL_CONTACT_POINT_VALUE.HOME, LABELS: ["HOME", "INTERNET"] },
	WORK: { CONTACT_POINT_VALUE: VCard._EMAIL_CONTACT_POINT_VALUE.WORK, LABELS: ["WORK", "INTERNET"] },
	OTHER: { CONTACT_POINT_VALUE: VCard._EMAIL_CONTACT_POINT_VALUE.OTHER, LABELS: ["INTERNET"] }
};

/////////////////// Urls ///////////////////////

VCard._URL_CONTACT_POINT_VALUE = {
	HOME: Url.TYPE.HOME,
	WORK: Url.TYPE.WORK,
	OTHER: Url.TYPE.OTHER
};

VCard.TYPES.URL = {
	HOME: { VCARD_VALUE: VCard.TYPEMARKERS.HOME, CONTACT_POINT_VALUE: VCard._URL_CONTACT_POINT_VALUE.HOME },
	WORK: { VCARD_VALUE: VCard.TYPEMARKERS.WORK, CONTACT_POINT_VALUE: VCard._URL_CONTACT_POINT_VALUE.WORK },
	OTHER: { CONTACT_POINT_VALUE: VCard._URL_CONTACT_POINT_VALUE.OTHER }
};

VCard.URL_LABELS = {
	HOME: { CONTACT_POINT_VALUE: VCard._URL_CONTACT_POINT_VALUE.WORK, LABELS: ["HOME"] },
	WORK: { CONTACT_POINT_VALUE: VCard._URL_CONTACT_POINT_VALUE.WORK, LABELS: ["WORK"] },
	OTHER: { CONTACT_POINT_VALUE: VCard._URL_CONTACT_POINT_VALUE.OTHER, LABELS: [] }
};

//////////////////// IM Addresses /////////////////

VCard._IMADDRESS_CONTACT_POINT_VALUE = {
	HOME: IMAddress.TYPE.HOME,
	WORK: IMAddress.TYPE.WORK,
	OTHER: IMAddress.TYPE.OTHER
};

VCard.TYPES.IM_ADDRESS = {
	HOME: { VCARD_VALUE: VCard.TYPEMARKERS.HOME, CONTACT_POINT_VALUE: VCard._IMADDRESS_CONTACT_POINT_VALUE.HOME },
	WORK: { VCARD_VALUE: VCard.TYPEMARKERS.WORK, CONTACT_POINT_VALUE: VCard._IMADDRESS_CONTACT_POINT_VALUE.WORK },
	OTHER: { CONTACT_POINT_VALUE: VCard._IMADDRESS_CONTACT_POINT_VALUE.OTHER }
};

VCard.IM_SERVICES = {
	GTALK: { VCARD_VALUE: VCard.MARKERS.GTALK, SERVICE_NAME: IMAddress.TYPE.GTALK, LABELS: [VCard.MARKERS.GTALK] },
	GOOGLE: { VCARD_VALUE: VCard.MARKERS.GTALK, SERVICE_NAME: IMAddress.TYPE.GTALK, LABELS: [VCard.MARKERS.GTALK] },
	AIM: { VCARD_VALUE: VCard.MARKERS.AIM, SERVICE_NAME: IMAddress.TYPE.AIM, LABELS: [VCard.MARKERS.AIM] },
	MSN: { VCARD_VALUE: VCard.MARKERS.MSN, SERVICE_NAME: IMAddress.TYPE.MSN, LABELS: [VCard.MARKERS.MSN] },
	YAHOO: { VCARD_VALUE: VCard.MARKERS.YAHOO, SERVICE_NAME: IMAddress.TYPE.YAHOO, LABELS: [VCard.MARKERS.YAHOO] },
	JABBER: { VCARD_VALUE: VCard.MARKERS.JABBER, SERVICE_NAME: IMAddress.TYPE.JABBER, LABELS: [VCard.MARKERS.JABBER] },
	QQ: { VCARD_VALUE: VCard.MARKERS.QQ, SERVICE_NAME: IMAddress.TYPE.QQ, LABELS: [VCard.MARKERS.QQ] },
	ICQ: { VCARD_VALUE: VCard.MARKERS.ICQ, SERVICE_NAME: IMAddress.TYPE.ICQ, LABELS: [VCard.MARKERS.ICQ] },
	SKYPE: { VCARD_VALUE: VCard.MARKERS.SKYPE, SERVICE_NAME: IMAddress.TYPE.SKYPE, LABELS: [VCard.MARKERS.SKYPE] },
	OTHER: { SERVICE_NAME: IMAddress.TYPE.DEFAULT, LABELS: [VCard.MARKERS.IM] }
};

//////////////////// Addresses //////////////////////

VCard._ADDRESS_CONTACT_POINT_VALUE = {
	HOME: Address.TYPE.HOME,
	WORK: Address.TYPE.WORK,
	OTHER: Address.TYPE.OTHER
};

VCard.TYPES.ADDRESS = {
	HOME: { VCARD_VALUE: VCard.TYPEMARKERS.HOME, CONTACT_POINT_VALUE: VCard._ADDRESS_CONTACT_POINT_VALUE.HOME },
	WORK: { VCARD_VALUE: VCard.TYPEMARKERS.WORK, CONTACT_POINT_VALUE: VCard._ADDRESS_CONTACT_POINT_VALUE.WORK },
	OTHER: { CONTACT_POINT_VALUE: VCard._ADDRESS_CONTACT_POINT_VALUE.OTHER }
};

VCard.ADDRESS_LABELS = {
	HOME: { CONTACT_POINT_VALUE: VCard._ADDRESS_CONTACT_POINT_VALUE.HOME, LABELS: ["HOME"] },
	WORK: { CONTACT_POINT_VALUE: VCard._ADDRESS_CONTACT_POINT_VALUE.WORK, LABELS: ["WORK"] },
	OTHER: { CONTACT_POINT_VALUE: VCard._ADDRESS_CONTACT_POINT_VALUE.OTHER, LABELS: ["OTHER"] }
};

//////////////////// Relation //////////////////////

VCard._RELATION_CONTACT_POINT_VALUE = {
	ASSISTANT: Relation.TYPE.ASSISTANT,
	BROTHER: Relation.TYPE.BROTHER,
	CHILD: Relation.TYPE.CHILD,
	DOMESTIC_PARTNER: Relation.TYPE.DOMESTIC_PARTNER,
	FATHER: Relation.TYPE.FATHER,
	FRIEND: Relation.TYPE.FRIEND,
	MANAGER: Relation.TYPE.MANAGER,
	MOTHER: Relation.TYPE.MOTHER,
	PARENT: Relation.TYPE.PARENT,
	PARTNER: Relation.TYPE.PARTNER,
	REFERRED_BY: Relation.TYPE.REFERRED_BY,
	RELATIVE: Relation.TYPE.RELATIVE,
	SISTER: Relation.TYPE.SISTER,
	SPOUSE: Relation.TYPE.SPOUSE,
	OTHER: Relation.TYPE.OTHER
};

VCard.TYPES.RELATION = {
	ASSISTANT: { VCARD_VALUE: VCard.TYPEMARKERS.ASSISTANT, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.ASSISTANT },
	BROTHER: { VCARD_VALUE: VCard.TYPEMARKERS.BROTHER, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.BROTHER },
	CHILD: { VCARD_VALUE: VCard.TYPEMARKERS.CHILD, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.CHILD },
	DOMESTIC_PARTNER: { VCARD_VALUE: VCard.TYPEMARKERS.DOMESTIC_PARTNER, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.DOMESTIC_PARTNER },
	FATHER: { VCARD_VALUE: VCard.TYPEMARKERS.FATHER, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.FATHER },
	FRIEND: { VCARD_VALUE: VCard.TYPEMARKERS.FRIEND, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.FRIEND },
	MANAGER: { VCARD_VALUE: VCard.TYPEMARKERS.MANAGER, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.MANAGER },
	MOTHER: { VCARD_VALUE: VCard.TYPEMARKERS.MOTHER, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.MOTHER },
	PARENT: { VCARD_VALUE: VCard.TYPEMARKERS.PARENT, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.PARENT },
	PARTNER: { VCARD_VALUE: VCard.TYPEMARKERS.PARTNER, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.PARTNER },
	REFERRED_BY: { VCARD_VALUE: VCard.TYPEMARKERS.REFERRED_BY, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.REFERRED_BY },
	RELATIVE: { VCARD_VALUE: VCard.TYPEMARKERS.RELATIVE, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.RELATIVE },
	SISTER: { VCARD_VALUE: VCard.TYPEMARKERS.SISTER, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.SISTER },
	SPOUSE: { VCARD_VALUE: VCard.TYPEMARKERS.SPOUSE, CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.SPOUSE },
	OTHER: { CONTACT_POINT_VALUE: VCard._RELATION_CONTACT_POINT_VALUE.OTHER }
};
